<?php
// Replace these values with your database credentials
$servername = "localhost";
$username = "username";
$password = "password";
$dbname = "CheckInOutDB";

// Create connection
$conn = new mysqli($servername, $username, $password, $dbname);

// Check connection
if ($conn->connect_error) {
    die(json_encode(['error' => 'Failed to connect to the database']));
}


header('Content-Type: application/json');

$action = $_REQUEST['action'] ?? '';

switch ($action) {
    case 'get_building_id':
        get_building_id($conn);
        break;
    case 'get_users':
        get_users($conn);
        break;
    case 'add_user':
        add_user($conn);
        break;
    case 'check_in_out':
        check_in_out($conn);
        break;
    case 'delete_user':
        delete_user($conn);
        break;
    default:
        echo json_encode(['error' => 'Invalid action']);
        break;
}

function get_building_id($conn) {
    $code = $_GET['code'] ?? '';

    if (empty($code)) {
        echo json_encode(['error' => 'Invalid building code']);
        return;
    }

    $sql = "SELECT id FROM buildings WHERE code = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $code);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        echo json_encode(['id' => $row['id']]);
    } else {
        echo json_encode(['error' => 'Invalid building code']);
    }
}

function get_users($conn) {
    $building_id = $_GET['building_id'] ?? '';

    if (empty($building_id)) {
        echo json_encode(['error' => 'Invalid building ID']);
        return;
    }

    $sql_present = "SELECT id, name, is_present FROM users WHERE building_id = ? AND is_present = 1";
    $sql_absent = "SELECT id, name, is_present FROM users WHERE building_id = ? AND is_present = 0";

    $stmt_present = $conn->prepare($sql_present);
    $stmt_present->bind_param("i", $building_id);
    $stmt_present->execute();
    $result_present = $stmt_present->get_result()->fetch_all(MYSQLI_ASSOC);

    $stmt_absent = $conn->prepare($sql_absent);
    $stmt_absent->bind_param("i", $building_id);
    $stmt_absent->execute();
    $result_absent = $stmt_absent->get_result()->fetch_all(MYSQLI_ASSOC);

    echo json_encode(['present' => $result_present, 'absent' => $result_absent]);
}

function add_user($conn) {
    $name = $_GET['name'] ?? '';
    $building_id = $_GET['building_id'] ?? '';

    if (empty($name) || empty($building_id)) {
        echo json_encode(['error' => 'Invalid user data']);
        return;
    }

    $sql = "INSERT INTO users (name, building_id) VALUES (?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("si", $name, $building_id);

    if ($stmt->execute()) {
       
echo json_encode(['success' => true]);
    } else {
        echo json_encode(['error' => 'Failed to add user']);
    }
}

function check_in_out($conn) {
    $user_id = $_POST['user_id'] ?? '';
    $is_present = $_POST['is_present'] ?? '';

    if (empty($user_id)) {
        echo json_encode(['error' => 'Invalid user ID']);
        return;
    }

    $sql = "UPDATE users SET is_present = ? WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ii", $is_present, $user_id);

    if ($stmt->execute()) {
        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['error' => 'Failed to update user status']);
    }
}

function delete_user($conn) {
    $user_id = $_POST['user_id'] ?? '';

    if (empty($user_id)) {
        echo json_encode(['error' => 'Invalid user ID']);
        return;
    }

    $sql = "DELETE FROM users WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);

    if ($stmt->execute()) {
        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['error' => 'Failed to delete user']);
    }
}

$conn->close();
