let currentBuildingId = sessionStorage.getItem('buildingId');

function showLoading() {
    $('#loading').show();
}

function hideLoading() {
    $('#loading').hide();
}

function showError(message) {
    $('#error-message').text(message);
    $('#error-message').show();
}

function hideError() {
    $('#error-message').text('');
    $('#error-message').hide();
}

function getUsers() {
    if (!currentBuildingId) {
        showError('Invalid building code. Please enter a valid building code.');
        return;
    }

    $.ajax({
        url: 'api.php',
        method: 'GET',
        cache: false,
        data: {
            action: 'get_users',
            building_id: currentBuildingId,
        },
        dataType: 'json',
        beforeSend: function() {
            showLoading();
        },
        success: function(response) {
            hideLoading();
            if (response.error) {
                showError(response.error);
            } else {
                populateUserLists(response.present, $('#users-present'));
                populateUserLists(response.absent, $('#users-absent'));
            }
        },
        error: function() {
            hideLoading();
            showError('Failed to fetch user data. Please try again.');
        },
    });
}

function populateUserLists(users, listElement) {
    listElement.empty();
    users.forEach(function(user) {
        const listItem = $('<li></li>');
        listItem.text(user.name);

        const checkInOutBtn = $('<button></button>');
        checkInOutBtn.text(user.is_present ? 'Check Out' : 'Check In');
        checkInOutBtn.addClass(user.is_present ? 'checkout-btn' : 'checkin-btn');
        checkInOutBtn.click(function() {
            checkInOutUser(user.id, !user.is_present);
        });

        const deleteBtn = $('<button>Delete</button>');
        deleteBtn.addClass('delete-btn');
        deleteBtn.click(function() {
            deleteUser(user.id);
        });

        listItem.append(' ', checkInOutBtn, ' ', deleteBtn);
        listElement.append(listItem);
    });
}

function checkInOutUser(userId, isPresent) {
    $.ajax({
        url: 'api.php',
        method: 'POST',
        cache: false,
        data: {
            action: 'check_in_out',
            user_id: userId,
            is_present: isPresent ? 1 : 0,
        },
        dataType: 'json',
        beforeSend: function() {
            showLoading();
        },
        success: function(response) {
            hideLoading();
            if (response.error) {
                showError(response.error);
            } else {
                getUsers();
            }
        },
        error: function() {
            hideLoading();
            showError('Failed to update user status. Please try again.');
        },
    });
}

function deleteUser(userId) {
    $.ajax({
        url: 'api.php',
        method: 'POST',
        cache: false,
        data: {
            action: 'delete_user',
            user_id: userId,
        },
        dataType: 'json',
        beforeSend: function() {
            showLoading();
        },
        success: function(response) {
            hideLoading();
            if (response.error) {
                showError(response.error);
            } else {
                getUsers();
            }
        },
        error: function() {
            hideLoading();
            showError('Failed to delete user. Please try again.');
        },
    });
}

function addUser() {
    const inputField = document.getElementById("new-user-name");
    const name = inputField.value.trim();
    
    if (name === "") {
        alert("Please enter a user's name.");
        return;
    }
    
    inputField.value = "";

    const buildingId = sessionStorage.getItem("buildingId");
    
    fetch(`api.php?action=add_user&name=${encodeURIComponent(name)}&building_id=${buildingId}`, {
        method: "POST",
    })
    .then((response) => {
        if (response.ok) {
            return response.json();
        } else {
            throw new Error("Error adding user.");
        }
    })
    .then((data) => {
        if (data.success) {
            populateUserLists();
        } else {
            alert("Error adding user.");
        }
    })
    .catch((error) => {
        console.error("Error:", error);
    });
}



function getBuildingId(code) {
    $.ajax({
        url: 'api.php',
        method: 'GET',
        cache: false,
        data: {
            action: 'get_building_id',
            code: code,
        },
        dataType: 'json',
        beforeSend: function() {
            showLoading();
        },
        success: function(response) {
            hideLoading();
            if (response.error) {
                showError(response.error);
            } else {
                currentBuildingId = response.id;
                sessionStorage.setItem('buildingId', currentBuildingId);
                getUsers();
            }
        },
        error: function() {
            hideLoading();
            showError('Failed to fetch building data. Please try again.');
        },
    });
}

$(document).ready(function() {
    if (currentBuildingId) {
        getUsers();
    } else {
        const code = prompt("Enter Building Code:");
        if (code) {
            getBuildingId(code);
        } else {
            showError("You must enter a building code to proceed.");
        }
    }

    $('#new-user-form').submit(function(event) {
        event.preventDefault();
        const name = $('#new-user-input').val();
        addUser(name);
        $('#new-user-input').val('');
    });
});
